/*******************************************************************************
 *	BDS Database Schema Update
 *	T.Barnaby,	BEAM Ltd,	2021-05-24
 *
 *	Update from schema 17 to 18
 *******************************************************************************
 *
 */

/* Update tables */
alter table `Calibrations` add column `rawCalibrationFrequency` Double NOT NULL default 0.0;
alter table `Calibrations` add column `rawCalibrationFactor` Double NOT NULL default 0.0;
alter table `Calibrations` add column `rawCalibrationUnits` text NOT NULL default "";
alter table `Calibrations` add column `waterLevel` Double NOT NULL default 0.0;

update `Calibrations` set `calibrationUnits` = 'm/s**2' where `calibrationUnits` = 'm/s^2';
update `Sensors` set `gainUnits` = 'm/s**2' where `gainUnits` = 'm/s^2';

alter table `StationLocations` add column `channel` VARCHAR(16)	NOT NULL default "";
alter table `StationLocations` drop primary key, add primary key (`startTime`,`endTime`,`network`,`station`,`channel`);

alter table `Responses` add column `decimationOffset` Double NOT NULL default 0.0;
alter table `Responses` add column `decimationDelay` Double NOT NULL default 0.0;
alter table `Responses` add column `decimationCorr` Double NOT NULL default 0.0;
alter table `Responses` add column `inputUnits` text NOT NULL default "";
alter table `Responses` add column `outputUnits` text NOT NULL default "";

alter table `ArrayChannels` add column `arrayOffsetEast` Double NOT NULL default 0.0;
alter table `ArrayChannels` add column `arrayOffsetNorth` Double NOT NULL default 0.0;

/* Update all array offsets into ArrayChannels table */
update ArrayChannels ac, StationLocations sl set ac.arrayOffsetEast=sl.arrayOffsetEast, ac.arrayOffsetNorth=sl.arrayOffsetNorth where ac.station=sl.station and (ac.channel=sl.channel or sl.channel='');

alter table `StationLocations` drop column `arrayOffsetEast`;
alter table `StationLocations` drop column `arrayOffsetNorth`;

alter table `Stations` add column `network` VARCHAR(64) NOT NULL default "";
alter table `Stations` drop primary key, add primary key (`network`,`station`);
alter table `ArrayChannels` add column `network` VARCHAR(64) NOT NULL default "";
alter table `Notes` add column `eventId` int NOT NULL default 0;

/* Events addition */
CREATE TABLE `Events` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`userId`		int(1)		NOT NULL,
	`type`			VARCHAR(64)	NOT NULL,
	`title`			text		NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`source`		VARCHAR(16)	NOT NULL,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`eventTime`		VARCHAR(26)	NOT NULL,
	`longitude`		Double		NOT NULL,
	`latitude`		Double		NOT NULL,
	`elevation`		Double		NOT NULL,
	`waterDepth`		Double		NOT NULL,
	`magnitude`		Double		NOT NULL,
	`magnitudeUnits`	VARCHAR(16)	NOT NULL,
	`description`		text		NOT NULL,
	`notes`			text		NOT NULL,
	`extra`			mediumblob	NOT NULL,
	`dataChannels`		mediumblob	NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`eventTime`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `SpecialChannels` (
	`id`			int(1)		NOT NULL unique auto_increment,
	`startTime`		VARCHAR(26)	NOT NULL,
	`endTime`		VARCHAR(26)	NOT NULL,
	`network`		VARCHAR(16)	NOT NULL,
	`station`		VARCHAR(16)	NOT NULL,
	`channel`		VARCHAR(16)	NOT NULL,
	`dataType`		VARCHAR(16)	NOT NULL,
	`description`		text		NOT NULL,
	`lastUpdate`		TIMESTAMP	NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
	KEY (`id`),
	PRIMARY KEY  (`startTime`,`endTime`,`network`,`station`,`channel`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

LOCK TABLES `SpecialChannels` WRITE;
INSERT INTO `SpecialChannels` (`startTime`,`endTime`,`network`,`station`,`channel`,`dataType`,`description`) VALUES ('0001-01-01','9999-01-01','','','^.*b$','ignore','Internal SpecialChannels');
UNLOCK TABLES;

UPDATE `Config` set `value` = '18' where `name` = 'SchemaVersion';
